## SPELLCHECKER

### Installation
```python
  pip install pyspellrecommender
```

### Usage

```python
  form pyspellrecommender import SpellRecommender

  sp = SpellRecommender()
  sp.recommend('randam')
```

### Output

<img width="1076" alt="screen shot 2019-01-03 at 4 23 25 pm" src="https://user-images.githubusercontent.com/12614476/50633609-08d04280-0f74-11e9-821e-a25f6812e625.png">
